package cn.wise.sc.cement.business.controller;


import cn.wise.sc.cement.business.entity.Project;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.*;
import cn.wise.sc.cement.business.model.vo.EntrustVo;
import cn.wise.sc.cement.business.service.IEntrustService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author ztw
 * @since 2020-08-24
 */
@Api(tags="委托管理")
@RestController
@RequestMapping("/business/entrust")
public class EntrustController {

	private static final Logger log = LoggerFactory.getLogger("EntrustController");

	@Autowired
	private IEntrustService entrustService;

	@ApiOperation(value = "委托分页列表")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status", value = "状态(0未审批，1已通过，2未通过，3样品处理，4派发)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientId", value = "委托单位id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String")
	})
	@GetMapping("/getPage")
	public BaseResponse getPage(PageQuery pageQuery, String startDate, String endDate, Integer status, Integer clientId, String projectName) {
		try {
			return entrustService.getPage(pageQuery, startDate, endDate, status, clientId, projectName);
		} catch (Exception e) {
			log.debug("委托分页列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "新增委托")
	@PostMapping("/create")
	public BaseResponse create(@RequestBody EntrustQuery query) {
		try {
			return entrustService.create(query);
		}catch (Exception e) {
			log.debug("新增委托{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "委托详情")
	@GetMapping("/{id}")
	public BaseResponse getDtail(@PathVariable Integer id){
		try {
			return entrustService.getDtail(id);
		}catch (Exception e){
			log.debug("委托详情{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "委托评审")
	@PostMapping("/approval")
	public BaseResponse approval(@RequestBody ApprovalQuery query) {
		try {
			return entrustService.approval(query);
		}catch (Exception e) {
			log.debug("委托评审{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "发送样品处理任务")
	@PostMapping("/handle")
	public BaseResponse handle(@RequestBody HandleQuery query) {
		try {
			return entrustService.handle(query);
		}catch (Exception e) {
			log.debug("发送样品处理任务{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "样品处理分页列表")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status", value = "状态(（0未接受，1接受，2完成）)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientId", value = "委托单位id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String")
	})
	@GetMapping("/getSampleHandlePage")
	public BaseResponse getSampleHandlePage(PageQuery pageQuery, String startDate, String endDate, Integer status, Integer clientId, String projectName) {
		try {
			return entrustService.getSampleHandlePage(pageQuery, startDate, endDate, status, clientId, projectName);
		} catch (Exception e) {
			log.debug("样品处理分页列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "接受样品处理任务")
	@PostMapping("/acceptHandle")
	public BaseResponse acceptHandle(Integer id) {
		try {
			return entrustService.acceptHandle(id);
		}catch (Exception e) {
			log.debug("接受样品处理任务{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "完成样品处理任务")
	@PostMapping("/finishHandle")
	public BaseResponse finishHandle(Integer id) {
		try {
			return entrustService.finishHandle(id);
		}catch (Exception e) {
			log.debug("完成样品处理任务{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "派发检测项目任务")
	@PostMapping("/distribution")
	public BaseResponse distribution(@RequestBody DistributionQuery query) {
		try {
			return entrustService.distribution(query);
		}catch (Exception e) {
			log.debug("派发检测项目任务{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "派发分页列表")
	@ApiImplicitParams(value = {
			@ApiImplicitParam(name = "startDate", value = "开始日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "endDate", value = "结束日期", paramType = "query", dataType = "String"),
			@ApiImplicitParam(name = "status", value = "状态(（0未接受，1接受，2完成）)", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "clientId", value = "委托单位id", paramType = "query", dataType = "Integer"),
			@ApiImplicitParam(name = "projectName", value = "项目名称", paramType = "query", dataType = "String")
	})
	@GetMapping("/getSampleDistributionPage")
	public BaseResponse getSampleDistributionPage(PageQuery pageQuery, String startDate, String endDate, Integer status, Integer clientId, String projectName) {
		try {
			return entrustService.getSampleDistributionPage(pageQuery, startDate, endDate, status, clientId, projectName);
		} catch (Exception e) {
			log.debug("派发分页列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "接受检测项目任务")
	@PostMapping("/acceptDistribution")
	public BaseResponse acceptDistribution(Integer id) {
		try {
			return entrustService.acceptDistribution(id);
		}catch (Exception e) {
			log.debug("接受检测项目任务{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "完成检测项目任务")
	@PostMapping("/finishDistribution")
	public BaseResponse finishDistribution(Integer id) {
		try {
			return entrustService.finishDistribution(id);
		}catch (Exception e) {
			log.debug("完成检测项目任务{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "数据校核")
	@PostMapping("/check")
	public BaseResponse check(CheckQuery query) {
		try {
			return entrustService.check(query);
		}catch (Exception e) {
			log.debug("数据校核{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}




}

