package cn.wise.sc.cement.business.service.impl;



import cn.wise.sc.cement.business.entity.EntityEnclosure;
import cn.wise.sc.cement.business.mapper.EntityEnclosureMapper;
import cn.wise.sc.cement.business.model.query.EnclosureQuery;
import cn.wise.sc.cement.business.service.IEntityEnclosureService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service
public class CommonServiceImpl {

	@Resource
	private EntityEnclosureMapper entityEnclosureMapper;
	@Autowired
	private IEntityEnclosureService entityEnclosureService;

	/**
	 * 生成编号
	 * @param prefix 编号前缀:  申请编号SQ
	 * @param counts 当天申请数量 生成的编号+1
	 * @return
	 */
	public String createNo(String prefix, int counts){
		SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");//注意月份是MM
		String date = sdf.format(new Date());
		int nextNo = counts+1;
		String tailNo = counts==0?"00"+nextNo:(counts<10?"00"+nextNo:(counts<100?"0"+nextNo:String.valueOf(nextNo)));
		String applyNo = prefix+date+tailNo;
		return applyNo;
	}



	/**
	 * 保存附件信息
	 * @param entityType  实体类型（0:用户(头像),1:合同附件,3设备校核附件，4标样材料）
	 * @param entityId    关联实体类id
	 * @param enclosureQueryList 上传的附件列表
	 */
	public Boolean saveEntityEnclosure(Integer entityType, Integer entityId, List<EnclosureQuery> enclosureQueryList ){
		Boolean ref = false;
		QueryWrapper<EntityEnclosure> wrapper = new QueryWrapper<>();
		wrapper.eq("entity_type", entityType);
		wrapper.eq("entity_id", entityId);
		List<EntityEnclosure> entityEnclosureList = entityEnclosureMapper.selectList(wrapper);
		if(entityEnclosureList != null && entityEnclosureList.size()>0){
			for(EntityEnclosure eeOld : entityEnclosureList){
				eeOld.setIsDeleted(0);
				entityEnclosureMapper.updateById(eeOld);
			}
		}
		if(enclosureQueryList != null && enclosureQueryList.size()>0){
			List<EntityEnclosure> eeList = new ArrayList<>();
			for(int i = 0; i < enclosureQueryList.size(); i++){
				EnclosureQuery enclosureDto = enclosureQueryList.get(i);
				EntityEnclosure ee = new EntityEnclosure();
				ee.setEntityId(entityId);
				ee.setEntityType(entityType);
				ee.setEnclosureUrl(enclosureDto.getEnclosureUrl());
				ee.setCreateTime(LocalDateTime.now());
				ee.setUpdateTime(ee.getCreateTime());
				ee.setIsDeleted(1);
				ee.setAlias(enclosureDto.getAlias());
				ee.setExtName(enclosureDto.getExtName());
				eeList.add(ee);
			}
			entityEnclosureService.saveBatch(eeList);
		}
		ref = true;
		return ref;
	}

	/**
	 * 根据实体类型 和实体类id获取附件列表
	 * @param entityType  实体类型（0:用户(头像),1:合同附件,3设备校核附件，4标样材料）
	 * @param entityId    关联实体类id
	 * @return
	 */
	public List<EntityEnclosure> getEnclosureList(Integer entityType,  Integer entityId){
		QueryWrapper<EntityEnclosure> wrapper = new QueryWrapper<>();
		wrapper.eq("entity_type", entityType);
		wrapper.eq("entity_id", entityId);
		List<EntityEnclosure> entityEnclosureList = entityEnclosureMapper.selectList(wrapper);
		return entityEnclosureList;
	}



















}
