package cn.wise.sc.cement.business.service.impl;

import cn.wise.sc.cement.business.entity.*;
import cn.wise.sc.cement.business.mapper.*;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.LoginUser;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.*;
import cn.wise.sc.cement.business.model.vo.*;
import cn.wise.sc.cement.business.service.*;
import cn.wise.sc.cement.business.wrapper.page.Query;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.models.auth.In;
import org.apache.commons.lang3.StringUtils;
import org.apache.tomcat.jni.Local;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import sun.print.BackgroundServiceLookup;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.*;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author ztw
 * @since 2020-08-24
 */
@Service
public class EntrustServiceImpl extends ServiceImpl<EntrustMapper, Entrust> implements IEntrustService {

	@Resource
	private EntrustMapper entrustMapper;
	@Autowired
	private ISampleTmpService sampleTmpService;
	@Autowired
	private ISysUserService userService;
	@Resource
	private TeamMapper teamMapper;
	@Autowired
	private CommonServiceImpl commonService;
	@Autowired
	private ISampleService sampleService;
	@Resource
	private EntrustApprovalMapper approvalMapper;
	@Autowired
	private ISysLogsService logsService;
	@Autowired
	private ISampleHandleService sampleHandleService;
	@Resource
	private SampleHandleMapper sampleHandleMapper;
	@Autowired
	private ISampleDistributionService distributionService;
	@Resource
	private SampleDistributionMapper distributionMapper;
	@Autowired
	private ISampleCheckService sampleCheckService;
	@Autowired
	private ISampleCheckTeamService sampleCheckTeamService;
	@Autowired
	private IEquipmentUseService equipmentUseService;
	@Resource
	private ProjectMapper projectMapper;

	/**
	 * 委托分页
	 * @param pageQuery
	 * @param startDate
	 * @param endDate
	 * @param status
	 * @param clientId
	 * @param projectName
	 * @return
	 */
	@Override
	public BaseResponse<IPage<EntrustVo>> getPage(PageQuery pageQuery, String startDate, String endDate, Integer status,
	                                              Integer clientId, String projectName){
		Map<String, Object> params = new HashMap<>();
		params.put("startDate", startDate);
		params.put("endDate", endDate);
		params.put("status", status);
		params.put("clientId", clientId);
		params.put("projectName", projectName);
		Page<EntrustVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<EntrustVo> pages = entrustMapper.getPage(page, params);
		List<EntrustVo> list = pages.getRecords();
		if(list != null && list.size()>0){
			for(EntrustVo entrustVo : list){
				QueryWrapper<SampleTmp> queryWrapper = new QueryWrapper<>();
				queryWrapper.eq("entrust_id", entrustVo.getId());
				List<SampleTmp> sampleTmpList = sampleTmpService.list(queryWrapper);
				//检测项目名称
				if(sampleTmpList != null && sampleTmpList.size()>0){
					SampleTmp sampleTmp = sampleTmpList.get(0);
					String teamIds = sampleTmp.getTeamIds();
					String checkTeam = "";
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								team.getName();
								checkTeam = checkTeam.equals("")?team.getName():(checkTeam+"、"+team.getName());
							}
						}
					}
					entrustVo.setCheckTeam(checkTeam);
				}
			}
		}
		pages.setRecords(list);
		return BaseResponse.okData(pages);
	}

	/**
	 * 新增委托
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<Entrust> create(EntrustQuery query){
		if(query.getClientId() == null){
			return BaseResponse.errorMsg("请选择委托单位");
		}
		if(query.getProjectId() == null || StringUtils.isEmpty(query.getProjectCode())){
			return BaseResponse.errorMsg("请选择项目");
		}
		if(StringUtils.isEmpty(query.getSendName()) || StringUtils.isEmpty(query.getSendPhone())){
			return BaseResponse.errorMsg("请填写送样人信息");
		}
		Entrust entrust = new Entrust();
		BeanUtils.copyProperties(query,entrust);
		//生成委托编号
		QueryWrapper<Entrust> entrustQueryWrapper = new QueryWrapper<>();
		entrustQueryWrapper.eq("create_time", LocalDateTime.now());
		String entrustCode = commonService.createNo("WT", this.count(entrustQueryWrapper));
		entrust.setEntrustCode(entrustCode)
				.setUserId(userService.getLoginUser()!=null?userService.getLoginUser().getId():1)
				.setStatus(0)
				.setIsDelete(1)
				.setIsHandle(0)
				.setIsDistribution(0)
				.setCreateTime(LocalDateTime.now())
				.setSampleNum(query.getSampleTmpList().size());
		entrustMapper.insert(entrust);
		if(query.getSampleTmpList() != null && query.getSampleTmpList().size()>0){
			List<SampleTmp> sampleTmpList = new ArrayList<>();
			for(SampleTmpQuery sampleTmpQuery : query.getSampleTmpList()){
				SampleTmp sampleTmp = new SampleTmp();
				BeanUtils.copyProperties(sampleTmpQuery, sampleTmp);
				sampleTmp.setEntrustId(entrust.getId()).setCreateTime(LocalDateTime.now());
				sampleTmpList.add(sampleTmp);
				//sampleTmpMapper.insert(sampleTmp);
			}
			sampleTmpService.saveBatch(sampleTmpList);
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "提交了委托单", null);
		return BaseResponse.okData(entrust);
	}

	/**
	 * 委托详情
	 * @param id
	 * @return
	 */
	@Override
	public BaseResponse<EntrustVo> getDtail(Integer id){
		if(id == null){
			return BaseResponse.errorMsg("参数错误");
		}
		EntrustVo entrustVo = entrustMapper.getDetail(id);
		if(entrustVo.getStatus()==1){
			QueryWrapper<Sample> sampleWrapper = new QueryWrapper<>();
			sampleWrapper.eq("entrust_id", entrustVo.getId());
			sampleWrapper.orderByAsc("id");
			List<Sample> sampleList = sampleService.list(sampleWrapper);
			List<SampleVo> sampleVoList = new ArrayList<>();
			if(sampleList!= null && sampleList.size()>0){
				for(Sample sample : sampleList){
					SampleVo sampleVo = new SampleVo();
					BeanUtils.copyProperties(sample,sampleVo);
					String teamIds = sample.getTeamIds();
					String teamName = "";
					List<SampleDistributionTeamVo>  sampleNoDistributionTeamVoList = new ArrayList<>();
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								teamName = teamName.equals("")?team.getName():(teamName+"、"+team.getName());
								SampleDistributionTeamVo distributionTeamVo = new SampleDistributionTeamVo();
								distributionTeamVo.setTeamId(team.getId());
								distributionTeamVo.setTeamName(team.getName());
								sampleNoDistributionTeamVoList.add(distributionTeamVo);
							}
						}
					}
					sampleVo.setTeamName(teamName);
					List<SampleDistributionTeamVo>  sampleDistributionTeamVoList =
							distributionMapper.getDistributionTeamList(sample.getId());
					if(sampleDistributionTeamVoList != null && sampleDistributionTeamVoList.size()>0) {
						sampleVo.setSampleDistributionTeamVoList(sampleDistributionTeamVoList);
					}else{
						sampleVo.setSampleDistributionTeamVoList(sampleNoDistributionTeamVoList);
					}
					sampleVoList.add(sampleVo);
				}
			}
			entrustVo.setSampleList(sampleVoList);
		}else{
			QueryWrapper<SampleTmp> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("entrust_id", entrustVo.getId());
			List<SampleTmp> sampleTmpList = sampleTmpService.list(queryWrapper);
			List<SampleTmpVo> sampleTmpVoList = new ArrayList<>();
			if(sampleTmpList!= null && sampleTmpList.size()>0){
				for(SampleTmp sampleTmp : sampleTmpList){
					SampleTmpVo sampleTmpVo = new SampleTmpVo();
					BeanUtils.copyProperties(sampleTmp,sampleTmpVo);
					String teamIds = sampleTmp.getTeamIds();
					String teamName = "";
					if(teamIds != null){
						String[] teamIdS = teamIds.split("、");
						for(String teamId : teamIdS){
							Team team = teamMapper.selectById(Integer.valueOf(teamId));
							if(team != null){
								team.getName();
								teamName = teamName.equals("")?team.getName():(teamName+"、"+team.getName());
							}
						}
					}
					sampleTmpVo.setTeamName(teamName);



					sampleTmpVoList.add(sampleTmpVo);
				}
			}
			entrustVo.setSampleTmpList(sampleTmpVoList);
		}
		return BaseResponse.okData(entrustVo);
	}

	/**
	 * 委托评审
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> approval(ApprovalQuery query){
		if(query.getId() == null || query.getIsAgree() == null){
			return BaseResponse.errorMsg("参数错误");
		}
		EntrustVo entrustVo = entrustMapper.getDetail(query.getId());
		if(entrustVo == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrustVo.getStatus() != 0){
			return BaseResponse.errorMsg("当前状态不允许评审");
		}
		Entrust entrust = entrustMapper.selectById(entrustVo.getId());

		if(query.getIsAgree() ==1){ //通过
			if(StringUtils.isEmpty(query.getProjectType())){
				return BaseResponse.errorMsg("请选择项目类型");
			}
			if(query.getSampleList() != null && query.getSampleList().size()>0){
				List<Sample> sampleList = new ArrayList<>();
				QueryWrapper<Sample> sampleQueryWrapper = new QueryWrapper<>();
				Integer nums = sampleService.count(sampleQueryWrapper);
				for(SampleQuery sampleQuery : query.getSampleList()){
					Sample sample = new Sample();
					BeanUtils.copyProperties(sampleQuery, sample);
					sample.setId(null)
							.setSampleId(sampleQuery.getId())
							.setStatus(0)  //样品状态为未领用状态
							.setCreateTime(LocalDateTime.now());
					if(sampleQuery.getIsParallel() ==1){ //平行样
						//生成本所编号
						String cementCode = commonService.createNo("BS", nums);
						String cementCode2 = commonService.createNo("BS", nums+1);
						sample.setCementCode(cementCode);
						sampleList.add(sample);
						Sample sample2 = new Sample();
						BeanUtils.copyProperties(sample, sample2);
						sample2.setCementCode(cementCode2);
						sampleList.add(sample2);
						nums = nums + 2;
					}else if(sampleQuery.getIsParallel() ==0){ //非平行样
						String cementCode = commonService.createNo("BS", nums);
						sample.setCementCode(cementCode);
						sampleList.add(sample);
						nums = nums + 1;
					}else{
						return BaseResponse.errorMsg("请选择是否需要平行样");
					}
				}
				sampleService.saveBatch(sampleList);
			}
			entrust.setStatus(1).setProjectType(query.getProjectType()).setUpdateTime(LocalDateTime.now());
			logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "修改评审状态为“通过”", null);
		}else if (query.getIsAgree() == 2){  //驳回
			entrust.setStatus(2).setUpdateTime(LocalDateTime.now());
			logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "修改评审状态为“驳回”", null);
		}else{
			return BaseResponse.errorMsg("请选择正确按钮");
		}
		//记录审批信息
		EntrustApproval entrustApproval = new EntrustApproval();
		LoginUser loginUser = userService.getLoginUser();
		entrustApproval.setEntrustId(entrust.getId())
				.setUserId(loginUser.getId())
				.setOpinion(query.getAuditReason())
				.setStatus(query.getIsAgree())
				.setCreateTime(LocalDateTime.now())
				.setRemark(null);
		approvalMapper.insert(entrustApproval);
		entrustMapper.updateById(entrust);

		return BaseResponse.okMsg("审批完成");
	}

	/**
	 * 发送样品处理任务
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> handle(HandleQuery query){
		if(query.getId() == null ){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = entrustMapper.selectById(query.getId());
		if(entrust == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrust.getStatus() != 1){
			return BaseResponse.errorMsg("当前状态不允许样品处理");
		}
		if(query.getSampleHandleQueryList() != null && query.getSampleHandleQueryList().size()>0){
			List<SampleHandleQuery> sampleHandleQueryList = query.getSampleHandleQueryList();
			List<SampleHandle> sampleHandleList = new ArrayList<>();
			for(SampleHandleQuery sampleHandleQuery : sampleHandleQueryList){
				SampleHandle sampleHandle = new SampleHandle();
				if(sampleHandleQuery.getSampleId() == null){
					return BaseResponse.errorMsg("样品信息错误");
				}
				if(sampleHandleQuery.getUserId() == null){
					return BaseResponse.errorMsg("请选择处理人");
				}
				if(StringUtils.isEmpty(sampleHandleQuery.getContent())){
					return BaseResponse.errorMsg("请填写处理项");
				}
				if(sampleHandleQuery.getPlanFinishDate() == null){
					return BaseResponse.errorMsg("请选择要求完成日期");
				}
				BeanUtils.copyProperties(sampleHandleQuery, sampleHandle);
				sampleHandle.setStatus(0).setCreateTime(LocalDateTime.now());
				sampleHandleList.add(sampleHandle);
			}
			sampleHandleService.saveBatch(sampleHandleList);
		}
		entrust.setIsHandle(1);
		entrustMapper.updateById(entrust);
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "发送样品处理任务", null);
		return BaseResponse.okMsg("已发送样品处理任务");
	}

	/**
	 * 样品处理分页
	 * @param pageQuery
	 * @param startDate
	 * @param endDate
	 * @param status
	 * @param clientId
	 * @param projectName
	 * @return
	 */
	@Override
	public BaseResponse<IPage<SampleHandleVo>> getSampleHandlePage(PageQuery pageQuery, String startDate, String endDate, Integer status,
	                                                   Integer clientId, String projectName){
		LoginUser loginUser = userService.getLoginUser();
		Map<String, Object> params = new HashMap<>();
		params.put("startDate", startDate);
		params.put("endDate", endDate);
		params.put("status", status);
		params.put("clientId", clientId);
		params.put("projectName", projectName);
		params.put("userId", loginUser.getId());
		Page<EntrustVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<SampleHandleVo> pages = sampleHandleMapper.getPage(page, params);
		return BaseResponse.okData(pages);
	}

	/**
	 * 接受样品处理任务
	 * @param id
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> acceptHandle(Integer id){
		if(id == null){
			return BaseResponse.errorMsg("参数错误");
		}
		SampleHandle sampleHandle = sampleHandleMapper.selectById(id);
		if(sampleHandle == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(sampleHandle.getStatus() != 0){
			return BaseResponse.errorMsg("状态错误");
		}
		sampleHandle.setStatus(1).setAcceptTime(LocalDateTime.now());
		sampleHandleMapper.updateById(sampleHandle);

		Sample sample = sampleService.getById(sampleHandle.getSampleId());
		if(sample == null){
			return BaseResponse.errorMsg("样品信息错误");
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, sample.getEntrustId(), "接受样品处理任务", null);
		return BaseResponse.okMsg("已接受样品处理任务");
	}

	/**
	 * 完成样品处理任务
	 * @param id
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> finishHandle(Integer id){
		if(id == null){
			return BaseResponse.errorMsg("参数错误");
		}
		SampleHandle sampleHandle = sampleHandleMapper.selectById(id);
		if(sampleHandle == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(sampleHandle.getStatus() != 1){
			return BaseResponse.errorMsg("状态错误");
		}
		sampleHandle.setStatus(2).setFinishTime(LocalDateTime.now());
		sampleHandleMapper.updateById(sampleHandle);

		Sample sample = sampleService.getById(sampleHandle.getSampleId());
		if(sample == null){
			return BaseResponse.errorMsg("样品信息错误");
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, sample.getEntrustId(), "完成样品处理任务", null);
		return BaseResponse.okMsg("已完成样品处理任务");
	}


	/**
	 * 派发检测项目任务
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> distribution(DistributionQuery query){
		if(query.getId() == null ){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = entrustMapper.selectById(query.getId());
		if(entrust == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrust.getStatus() != 1){
			return BaseResponse.errorMsg("当前状态不允许派发");
		}
		entrust.setRemark(query.getRemark());
		if(query.getSampleDistributionQueryList() != null && query.getSampleDistributionQueryList().size()>0){
			List<SampleDistributionQuery> sampleDistributionQueryList = query.getSampleDistributionQueryList();
			List<SampleDistribution> sampleDistributionList = new ArrayList<>();
			List<Sample> sampleList = new ArrayList<>();
			for(SampleDistributionQuery distributionQuery : sampleDistributionQueryList){
				if(distributionQuery==null || distributionQuery.getSampleId() == null){
					return BaseResponse.errorMsg("样品信息错误");
				}
				if(distributionQuery.getSampleDistributionTeamQueryList() != null && distributionQuery.getSampleDistributionTeamQueryList().size()>0){
					List<SampleDistributionTeamQuery> sampleDistributionTeamQueryList = distributionQuery.getSampleDistributionTeamQueryList();
					for(SampleDistributionTeamQuery distributionTeamQuery : sampleDistributionTeamQueryList){
						if(distributionTeamQuery==null || distributionTeamQuery.getTeamId()== null){
							return BaseResponse.errorMsg("检测项信息错误");
						}
						if(distributionTeamQuery.getUserId() == null){
							return BaseResponse.errorMsg("请选择检测人员");
						}
						SampleDistribution sampleDistribution = new SampleDistribution();
						sampleDistribution.setSampleId(distributionQuery.getSampleId())
								.setTeamId(distributionTeamQuery.getTeamId())
								.setUserId(distributionTeamQuery.getUserId())
								.setStatus(0)
								.setCreateTime(LocalDateTime.now());
						sampleDistributionList.add(sampleDistribution);
					}
				}
				Sample sample = sampleService.getById(distributionQuery.getSampleId());
				if(sample == null ){
					return BaseResponse.errorMsg("样品信息错误");
				}
				sample.setStatus(1); //样品状态改成已领用状态
				sampleList.add(sample);
			}
			distributionService.saveBatch(sampleDistributionList);
			sampleService.updateBatchById(sampleList);
		}
		entrust.setIsDistribution(1);
		entrustMapper.updateById(entrust);
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "派发检测项目任务", null);
		return BaseResponse.okMsg("已派发检测项目任务");
	}


	/**
	 * 派发分页
	 * @param pageQuery
	 * @param startDate
	 * @param endDate
	 * @param status
	 * @param clientId
	 * @param projectName
	 * @return
	 */
	@Override
	public BaseResponse<IPage<SampleDistributionVo>> getSampleDistributionPage(PageQuery pageQuery, String startDate, String endDate, Integer status,
	                                                               Integer clientId, String projectName){
		LoginUser loginUser = userService.getLoginUser();
		Map<String, Object> params = new HashMap<>();
		params.put("startDate", startDate);
		params.put("endDate", endDate);
		params.put("status", status);
		params.put("clientId", clientId);
		params.put("projectName", projectName);
		params.put("userId", loginUser.getId());
		Page<SampleDistributionVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<SampleDistributionVo> pages = distributionMapper.getPage(page, params);
		return BaseResponse.okData(pages);
	}

	/**
	 * 接受检测项目任务
	 * @param id
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> acceptDistribution(Integer id){
		if(id == null){
			return BaseResponse.errorMsg("参数错误");
		}
		SampleDistribution distribution = distributionMapper.selectById(id);
		if(distribution == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(distribution.getStatus() != 0){
			return BaseResponse.errorMsg("状态错误");
		}
		distribution.setStatus(1).setAcceptTime(LocalDateTime.now());
		distributionMapper.updateById(distribution);
		Sample sample = sampleService.getById(distribution.getSampleId());
		if(sample == null){
			return BaseResponse.errorMsg("样品信息错误");
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, sample.getEntrustId(), "接受检测项目任务", null);
		return BaseResponse.okMsg("已接受检测项目任务");
	}

	/**
	 * 完成检测项目任务
	 * @param id
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> finishDistribution(Integer id){
		if(id == null){
			return BaseResponse.errorMsg("参数错误");
		}
		SampleDistribution distribution = distributionMapper.selectById(id);
		if(distribution == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(distribution.getStatus() != 1){
			return BaseResponse.errorMsg("状态错误");
		}
		distribution.setStatus(2).setFinishTime(LocalDateTime.now());
		distributionMapper.updateById(distribution);
		Sample sample = sampleService.getById(distribution.getSampleId());
		if(sample == null){
			return BaseResponse.errorMsg("样品信息错误");
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, sample.getEntrustId(), "完成检测项目任务", null);
		return BaseResponse.okMsg("已完成检测项目任务");
	}


	/**
	 * 数据校核
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> check(CheckQuery query){
		if(query.getId() == null ){
			return BaseResponse.errorMsg("参数错误");
		}
		Entrust entrust = entrustMapper.selectById(query.getId());
		if(entrust == null){
			return BaseResponse.errorMsg("信息错误");
		}
		if(entrust.getStatus() != 1){
			return BaseResponse.errorMsg("当前状态不允许校核");
		}
		LoginUser loginUser = userService.getLoginUser();
		if(loginUser == null){
			return BaseResponse.errorMsg("请登录用户");
		}
		Project project = projectMapper.selectById(entrust.getProjectId());
		if(project == null || entrust.getProjectId() == null){
			return BaseResponse.errorMsg("项目信息有误");
		}
		if(query.getSampleCheckQueryList() != null && query.getSampleCheckQueryList().size()>0){
			List<SampleCheckQuery> sampleCheckQueryList = query.getSampleCheckQueryList();
			List<EquipmentUse> useList = new ArrayList<>();
			for(SampleCheckQuery checkQuery : sampleCheckQueryList){
				if(checkQuery==null || checkQuery.getSampleId() == null){
					return BaseResponse.errorMsg("样品信息错误");
				}
				//保存样品 基本元素检测结果   比表面积校核结果
				Sample sample = sampleService.getById(checkQuery.getSampleId());
				sample.setBaseResult(checkQuery.getBaseResult())
						.setSurfaceResult(checkQuery.getSurfaceResult());
				sampleService.save(sample);
				//保存校核表信息
				SampleCheck check = new SampleCheck();
				check.setSampleId(checkQuery.getSampleId())
						.setUserId(loginUser.getId())
						.setEquipmentId(checkQuery.getEquipmentId())
						.setEquipmentName(checkQuery.getEquipmentName())
						.setCreateTime(LocalDateTime.now());
				sampleCheckService.save(check);
				String testItems = "";
				if(checkQuery.getSampleCheckTeamQueryList() != null && checkQuery.getSampleCheckTeamQueryList().size()>0){
					List<SampleCheckTeam> sampleCheckTeamList = new ArrayList<>();
					List<SampleCheckTeamQuery> sampleCheckTeamQueryList = checkQuery.getSampleCheckTeamQueryList();
					for(SampleCheckTeamQuery checkTeamQuery : sampleCheckTeamQueryList){
						if(checkTeamQuery==null ){
							return BaseResponse.errorMsg("检测样品信息错误");
						}
						if(checkTeamQuery.getTestItemId()== null || StringUtils.isEmpty(checkTeamQuery.getTestItem())){
							return BaseResponse.errorMsg("检测项目信息错误");
						}

						if(StringUtils.isEmpty(checkTeamQuery.getTestTeams())){
							return BaseResponse.errorMsg("请录入校核结果");
						}


						SampleCheckTeam sampleCheckTeam = new SampleCheckTeam();
						sampleCheckTeam.setCheckId(check.getId())
								.setTestItemId(checkTeamQuery.getTestItemId())
								.setTestItem(checkTeamQuery.getTestItem())
								.setTestTeams(checkTeamQuery.getTestTeams())
								.setCreateTime(LocalDateTime.now())
								.setRemark(checkTeamQuery.getRemark());
						sampleCheckTeamList.add(sampleCheckTeam);
						testItems = testItems.equals("")?sampleCheckTeam.getTestItem():testItems+"、"+sampleCheckTeam.getTestItem();
					}
					sampleCheckTeamService.saveBatch(sampleCheckTeamList);
				}
				//添加设备使用记录  设备使用记录表 equipment_use
				EquipmentUse equipmentUse = new EquipmentUse();
				equipmentUse.setEquipmentId(check.getEquipmentId())
						.setUserId(check.getUserId())
						.setUserName(loginUser.getName())
						.setUseDate(LocalDate.now())
						.setProjectId(project.getId())
						.setProjectName(project.getName())
						.setProjectCode(project.getCode())
						.setTestItem(testItems)
						.setCreateTime(LocalDateTime.now())
						.setRemark("委托派发-数据校核");

				useList.add(equipmentUse);
			}
			equipmentUseService.saveBatch(useList);
		}
		logsService.saveLog(SysLogs.ObjType.ENTRUST_LOG, entrust.getId(), "数据校核", null);
		return BaseResponse.okMsg("数据校核完成");
	}

















}
