package cn.wise.sc.cement.business.service.impl;

import cn.wise.sc.cement.business.entity.Sample;
import cn.wise.sc.cement.business.mapper.SampleMapper;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.SampleManageQuery;
import cn.wise.sc.cement.business.model.vo.SampleVo;
import cn.wise.sc.cement.business.service.ISampleService;
import cn.wise.sc.cement.business.service.ISysUserService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author ztw
 * @since 2020-08-24
 */
@Service
public class SampleServiceImpl extends ServiceImpl<SampleMapper, Sample> implements ISampleService {

	@Resource
	private SampleMapper sampleMapper;
	@Autowired
	private ISysUserService userService;



	/**
	 * 分页列表
	 * @param pageQuery
	 * @param sampleName
	 * @param cementCode
	 * @return
	 */
	@Override
	public BaseResponse<IPage<SampleVo>> getPage(PageQuery pageQuery, String sampleName, String cementCode){
		Map<String, Object> params = new HashMap<>();
		params.put("sampleName", sampleName);
		params.put("cementCode", cementCode);
		Page<SampleVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
		IPage<SampleVo> pages = sampleMapper.getPage(page, params);
		return BaseResponse.okData(pages);
	}

	/**
	 *  样品管理详情
	 * @param id
	 * @return
	 */
	@Override
	public BaseResponse<SampleVo> getDetail(Integer id){
		SampleVo sampleVo = sampleMapper.getDetail(id);
		if(sampleVo == null ){
			return BaseResponse.errorMsg("信息错误!");
		}
		return BaseResponse.okData(sampleVo);
	}

	/**
	 * 样品登记
	 * @param query
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> register(SampleManageQuery query) {
		if (query.getId() == null) {
			return BaseResponse.errorMsg("参数错误!");
		}
		Sample sample = sampleMapper.selectById(query.getId());
		if(sample == null){
			return BaseResponse.errorMsg("信息错误");
		}
		sample.setOperatorId(userService.getLoginUser().getId())
				.setRegisterTime(LocalDateTime.now())
				.setHandleDate(query.getHandleDate())
				.setLittlePosition(query.getLittlePosition())
				.setOriginalPosition(query.getOriginalPosition())
				.setRemark(query.getRemark());
		return BaseResponse.okData("样品登记成功");
	}

	/**
	 * 样品销毁
	 * @param id
	 * @return
	 */
	@Transactional
	@Override
	public BaseResponse<String> destruction(Integer id) {
		if (id == null) {
			return BaseResponse.errorMsg("参数错误!");
		}
		Sample sample = sampleMapper.selectById(id);
		if(sample == null){
			return BaseResponse.errorMsg("信息错误");
		}
		sample.setStatus(2)
				.setDestructionTime(LocalDateTime.now());
		sampleMapper.updateById(sample);
		return BaseResponse.okData("样品已销毁");
	}





}
